<a id="harlem.common"></a>

# harlem.common

<a id="harlem.common.to_har_model"></a>

#### to\_har\_model

```python
def to_har_model(pages: List[Page], entries: List[Entry]) -> Har
```

[[view_source]](https://github.com/WolfDWyc/harlem/blob/9f8f46048005256a8222ca316913bf605877223c/harlem\common.py#L28)

